Preprocessing Modules
======================
These modules contain functions to reduce
the number of candidate sources associated with a 
transient, calculate relevant attributes, and 
combine the output of association pipeline into a final 
Pandas DataFrame.

sourceCleaning
----------------------------------

.. automodule:: astro_ghost.sourceCleaning
   :members:
   :undoc-members:
   :show-inheritance:

stellarLocus
--------------------------------

.. automodule:: astro_ghost.stellarLocus
   :members:
   :undoc-members:
   :show-inheritance:

starSeparation
----------------------------------

.. automodule:: astro_ghost.starSeparation
   :members:
   :undoc-members:
   :show-inheritance:

hostMatching
--------------------------------

.. automodule:: astro_ghost.hostMatching
   :members:
   :undoc-members:
   :show-inheritance:
